@@ -2,6 +2,10 @@
 		
 	kind "StaticLib"
 	
+	if os.is("Linux") then
+	    buildoptions{"-fPIC"}
+	end
+	 
 	includedirs {
 		"../../../src"
 	}
