@@ -7,16 +7,18 @@ else
 	kind "ConsoleApp"
 end
 
-includedirs {"../../public"}
+includedirs {"../../public",
+"../../../src"}
 
 links {
-	"vhacd"
+	"vhacd", "LinearMath"
 }
 
 language "C++"
 
 files {
 	"main.cpp",
+	"main_vhacd.cpp",
 }
 
 
