@@ -1,6 +1,9 @@
 	project "BulletInverseDynamics"
 
 	kind "StaticLib"
+    if os.is("Linux") then
+        buildoptions{"-fPIC"}
+    end
 	includedirs {
 		"..",
 	}
